@@ -14,6 +14,7 @@ from pkg_resources import resource_filename
 from typing import Any
 
 import pretty_midi
+import yaml
 from sinethesizer.io import (
     convert_events_to_timeline,
     convert_tsv_to_events,
@@ -63,7 +64,7 @@ def create_midi_from_fragment(
     numeration_shift = pretty_midi.note_name_to_number('A0')
     pretty_midi_instruments = []
     for line_id, melodic_line in zip(fragment.line_ids, fragment.melodic_lines):
-        pretty_midi_instrument = pretty_midi.Instrument(instruments[line_id])
+        pretty_midi_instrument = pretty_midi.Instrument(instruments[line_id], name=str(line_id))
         for event in melodic_line:
             if event.pitch_class in ['pause', 'skip']:
                 continue
@@ -170,25 +171,16 @@ def create_tsv_events_from_fragment(
             out_file.write(line + '\n')
 
 
-def create_sinethesizer_instruments(n_melodic_lines: int) -> dict[str, Instrument]:
+def create_sinethesizer_instruments() -> dict[str, Instrument]:
     """
-    Create registry of `sinethesizer` instruments with adjusted amplitudes.
+    Create registry of `sinethesizer` instruments.
 
-    :param n_melodic_lines:
-        number of melodic lines in a fragment
     :return:
         mapping from instrument names to instruments itself
     """
     presets_path = resource_filename('dodecaphony', 'configs/sinethesizer_presets.yml')
     instruments_registry = create_instruments_registry(presets_path)
-    normalized_registry = {}
-    for name, instrument in instruments_registry.items():
-        amplitude_scaling = instrument.amplitude_scaling
-        amplitude_scaling /= n_melodic_lines
-        normalized_registry[name] = Instrument(
-            instrument.partials, amplitude_scaling, instrument.effects
-        )
-    return normalized_registry
+    return instruments_registry
 
 
 def create_wav_from_tsv_events(
@@ -213,6 +205,7 @@ def create_wav_from_tsv_events(
     settings = {
         'frame_rate': 48000,
         'trailing_silence': trailing_silence_in_seconds,
+        'peak_amplitude': 1,
         'instruments_registry': instruments_registry,
     }
     events = convert_tsv_to_events(events_path, settings)
@@ -220,6 +213,30 @@ def create_wav_from_tsv_events(
     write_timeline_to_wav(output_path, timeline, settings['frame_rate'])
 
 
+def create_yaml_from_fragment(fragment: Fragment, yaml_path: str) -> None:
+    """
+    Create YAML file that can be used for setting temporal and sonic content in a runtime config.
+
+    :param fragment:
+        musical fragment
+    :param yaml_path:
+        path to a file where result is going to be saved
+    :return:
+        None
+    """
+    temporal_content = {
+        i: {'durations': durations}
+        for i, durations in enumerate(fragment.temporal_content)
+    }
+    sonic_content = {
+        i: {'pitch_classes': pitch_classes}
+        for i, pitch_classes in enumerate(fragment.sonic_content)
+    }
+    result = {'temporal_content': temporal_content, 'sonic_content': sonic_content}
+    with open(yaml_path, 'w') as out_file:
+        yaml.dump(result, out_file)
+
+
 def make_lilypond_template(
         n_voices: int,
         tonic: str,
@@ -520,10 +537,12 @@ def render(fragment: Fragment, rendering_params: dict[str, Any]) -> None:  # pra
     create_tsv_events_from_fragment(fragment, events_path, **events_params, **common_params)
 
     wav_path = os.path.join(nested_dir, 'music.wav')
-    n_melodic_lines = len(fragment.melodic_lines)
-    instruments_registry = create_sinethesizer_instruments(n_melodic_lines)
+    instruments_registry = create_sinethesizer_instruments()
     create_wav_from_tsv_events(events_path, wav_path, instruments_registry, trailing_silence_in_sec)
 
+    yaml_path = os.path.join(nested_dir, 'content.yml')
+    create_yaml_from_fragment(fragment, yaml_path)
+
     lilypond_path = os.path.join(nested_dir, 'sheet_music.ly')
     create_lilypond_file_from_fragment(fragment, lilypond_path)
     create_pdf_sheet_music_with_lilypond(lilypond_path)
